==> paddlepaddle-2.6.2-cp38-cp38-macosx_11_0_arm64.whl: paddle/jit/sot/opcode_translator/executor/variables/__init__.py <==
# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .base import (  # noqa: F401
    ConstTypes,
    VariableBase,
    VariableFactory,
    find_traceable_vars,
    map_variables,
)
from .basic import (  # noqa: F401
    CellVariable,
    ConstantVariable,
    DataVariable,
    DygraphTracerVariable,
    FunctionGlobalVariable,
    GlobalVariable,
    ModuleVariable,
    NullVariable,
    NumpyVariable,
    ObjectVariable,
    SliceVariable,
    TensorVariable,
)
from .callable import (  # noqa: F401
    BuiltinVariable,
    CallableVariable,
    ClassVariable,
    ContainerLayerVariable,
    FunctionVariable,
    LayerVariable,
    MethodVariable,
    PaddleApiVariable,
    PaddleLayerVariable,
    UserDefinedFunctionVariable,
    UserDefinedGeneratorVariable,
    UserDefinedLayerVariable,
)
from .container import (  # noqa: F401
    ContainerVariable,
    DictVariable,
    ListVariable,
    RangeVariable,
    TupleVariable,
)
from .iter import (  # noqa: F401
    EnumerateVariable,
    IterVariable,
    MapVariable,
    SequenceIterVariable,
    UserDefinedIterVariable,
)

==> paddlepaddle-3.0.0b0-cp38-cp38-macosx_11_0_arm64.whl: paddle/jit/sot/opcode_translator/executor/variables/__init__.py <==
# Copyright (c) 2023 PaddlePaddle Authors. All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from .base import (  # noqa: F401
    VariableBase,
    VariableFactory,
    find_traceable_vars,
    map_variables,
)
from .basic import (  # noqa: F401
    CellVariable,
    ConstantVariable,
    DataVariable,
    DygraphTracerVariable,
    FunctionGlobalVariable,
    GlobalVariable,
    ModuleVariable,
    NullVariable,
    NumpyVariable,
    ObjectVariable,
    ParameterVariable,
    SliceVariable,
    SymbolicVariable,
    TensorVariable,
)
from .callable import (  # noqa: F401
    BuiltinVariable,
    CallableVariable,
    ClassVariable,
    ContainerLayerVariable,
    FunctionVariable,
    LayerVariable,
    MethodVariable,
    PaddleApiVariable,
    PaddleLayerVariable,
    UserDefinedFunctionVariable,
    UserDefinedGeneratorFunctionVariable,
    UserDefinedLayerVariable,
)
from .container import (  # noqa: F401
    ContainerVariable,
    DictVariable,
    ListVariable,
    RangeVariable,
    TupleVariable,
)
from .iter import (  # noqa: F401
    EnumerateVariable,
    IterVariable,
    MapVariable,
    SequenceIterVariable,
    UserDefinedIterVariable,
    ZipVariable,
)
